@@ -340,7 +340,30 @@ class CPLEX(ILMLicensedSystemCallSolver):
         return results
 
     def process_soln_file(self,results):
-        lp_solution=False
+
+        # the only suffixes that we extract from CPLEX are
+        # constraint duals, constraint slacks, and variable 
+        # reduced-costs. scan through the solver suffix list 
+        # and throw an exception if the user has specified 
+        # any others.
+        extract_duals = False
+        extract_slacks = False
+        extract_reduced_costs = False
+        for suffix in self.suffixes:
+           flag=False
+           if re.match(suffix,"dual"):
+                extract_duals = True
+                flag=True
+           if re.match(suffix,"slack"):
+                extract_slacks = True              
+                flag=True
+           if re.match(suffix,"rc"):
+                extract_reduced_costs = True
+                flag=True
+           if not flag:
+              raise RuntimeError,"***CPLEX solver plugin cannot extract solution suffix="+suffix
+
+        lp_solution = False
         if not os.path.exists(self.soln_file):
            return
 
@@ -367,9 +390,9 @@ class CPLEX(ILMLicensedSystemCallSolver):
                       variable_name = field_value
                    elif field_name == "value":
                       variable_value = field_value
-                   elif field_name == "reducedCost":
+                   elif (extract_reduced_costs is True) and (field_name == "reducedCost"):
                       variable_reduced_cost = field_value
-                   elif field_name == "status":
+                   elif (extract_reduced_costs is True) and (field_name == "status"):
                       variable_status = field_value
 
                 # skip the "constant-one" variable, used to capture/retain objective offsets in the CPLEX LP format.
@@ -380,7 +403,7 @@ class CPLEX(ILMLicensedSystemCallSolver):
                        variable.value = eval(variable_value)
                    except:
                        variable.value = variable_value
-                   if not variable_reduced_cost is None:
+                   if (variable_reduced_cost is not None) and (extract_reduced_costs is True):
                         try:
                             variable.rc = eval(variable_reduced_cost)
                             if variable_status is not None:
@@ -394,7 +417,7 @@ class CPLEX(ILMLicensedSystemCallSolver):
                                   variable.urc = 0.0
                         except:
                             raise ValueError, "Unexpected reduced-cost value="+str(variable_reduced_cost)+" encountered for variable="+variable_name
-            elif tokens[0] == "constraint":
+            elif (tokens[0] == "constraint") and ((extract_duals is True) or (extract_slacks is True)):
                 constraint_name = None
                 constraint_dual = None
                 constaint = None # cache the solution constraint reference, as the getattr is expensive.
@@ -404,11 +427,11 @@ class CPLEX(ILMLicensedSystemCallSolver):
                    if field_name == "name":
                       constraint_name = field_value
                       constraint = soln.constraint[constraint_name]
-                   elif field_name == "dual": # for LPs
+                   elif (extract_duals is True) and (field_name == "dual"): # for LPs
                       # assumes the name field is first.
                       if eval(field_value) != 0.0:
                         constraint.dual = eval(field_value)
-                   elif field_name == "slack": # for MIPs
+                   elif (extract_slacks is True) and (field_name == "slack"): # for MIPs
                       # assumes the name field is first.
                       if eval(field_value) != 0.0:
                         constraint.slack = eval(field_value)
