@@ -163,6 +163,8 @@ class GLPK(SystemCallSolver):
              soln.status = SolutionStatus.optimal
           elif len(tokens) > 2 and tokens[0] == "INTEGER" and tokens[1] == "OPTIMAL":
              soln.status = SolutionStatus.optimal
+             results.solver.statistics.branch_and_bound.number_of_created_subproblems = 0
+             results.solver.statistics.branch_and_bound.number_of_bounded_subproblems = 0
           elif len(tokens) > 2 and tokens[0] == "TIME" and tokens[2] == "EXCEEDED;":
              soln.status = SolutionStatus.stoppedByLimit
         if results.problem.upper_bound == "inf":
@@ -212,6 +214,19 @@ class GLPK(SystemCallSolver):
 
     def process_soln_file(self,results):
 
+        # the only suffixes that we extract from GLPK are
+        # constraint duals. scan through the solver suffix
+        # list and throw an exception if the user has 
+        # specified any others.
+        extract_duals = False
+        for suffix in self.suffixes:
+            flag=False
+            if re.match(suffix,"dual"):
+                extract_duals = True
+                flag=True
+            if not flag:
+                raise RuntimeError,"***GLPK solver plugin cannot extract solution suffix="+suffix
+
         lp_solution = True # if false, we're dealing with a MIP!
         if not os.path.exists(self.soln_file):
            return
@@ -360,7 +375,7 @@ class GLPK(SystemCallSolver):
                    # sanity check - the indices should be in sequence.
                    if index != number_of_constraints_read:
                       raise ValueError,"***ERROR: Unexpected constraint index encountered on line="+line+"; expected value="+str(number_of_constraints_read)+"; actual value="+str(index)
-
+   
                 if lp_solution is True:
                    # GLPK doesn't report slacks directly.
                    constraint_dual = activity
@@ -371,7 +386,8 @@ class GLPK(SystemCallSolver):
                    else:
                       raise ValueError, "Unknown status="+tokens[0]+" encountered for constraint="+active_constraint_name+" in line="+line+" of solution file="+self.soln_file
 
-                   soln.constraint[constraint_name].dual = constraint_dual
+                   if extract_duals is True:
+                      soln.constraint[constraint_name].dual = constraint_dual
                   
                 else:
                    # there isn't anything interesting to do with constraints in the MIP case.
@@ -428,7 +444,7 @@ class GLPK(SystemCallSolver):
 
                 if lp_solution is True:
                    state_string = line[20:22].strip()
-                   marginal_string = line[65:78].strip()                               
+                   marginal_string = line[65:78].strip()
 
                    if (activity_string != "< eps") and (len(activity_string) > 0):
                       activity = eval(activity_string)
